part of masamune_purchase;

class MobilePurchaseAdapter extends PurchaseAdapter<MobilePurchaseProduct> {
  const MobilePurchaseAdapter({
    required this.products,
    this.onPrepare,
    this.onVerify,
    this.onSubscribe,
    this.onUnlock,
    this.onDeliver,
    this.onCheckSubscription,
    this.subscribeOptions = const SubscribeOptions(),
    this.autoConsumeOnAndroid = true,
    this.androidRefreshToken,
    this.userId,
    this.androidVerifierOptions = const AndroidVerifierOptions(),
    this.iosVerifierOptions = const IOSVerifierOptions(),
    this.deliverOptions = const DeliverOptions(),
  });

  final List<PurchaseProduct> products;
  final Future<bool> Function()? onPrepare;
  final Future<bool> Function(PurchaseDetails purchase,
      MobilePurchaseProduct product, PurchaseModel core)? onVerify;
  final Future<void> Function(PurchaseDetails purchase,
      MobilePurchaseProduct product, PurchaseModel core)? onSubscribe;
  final Future<void> Function(PurchaseDetails purchase,
      MobilePurchaseProduct product, PurchaseModel core)? onUnlock;
  final Future<void> Function(PurchaseDetails purchase,
      MobilePurchaseProduct product, PurchaseModel core)? onDeliver;
  final Future<void> Function(PurchaseModel core)? onCheckSubscription;
  final SubscribeOptions subscribeOptions;
  final bool autoConsumeOnAndroid;
  final String? androidRefreshToken;
  final String? userId;
  final AndroidVerifierOptions androidVerifierOptions;
  final IOSVerifierOptions iosVerifierOptions;
  final DeliverOptions deliverOptions;

  @override
  Future<void> initialize() async {
    await PurchaseCore.initialize(
      products: products.map((e) => MobilePurchaseProduct.from(e)).toList(),
      onPrepare: onPrepare,
      onVerify: onVerify,
      onSubscribe: onSubscribe,
      onUnlock: onUnlock,
      onDeliver: onDeliver,
      onCheckSubscription: onCheckSubscription,
      subscribeOptions: subscribeOptions,
      autoConsumeOnAndroid: autoConsumeOnAndroid,
      androidRefreshToken: androidRefreshToken,
      userId: userId,
      androidVerifierOptions: androidVerifierOptions,
      iosVerifierOptions: iosVerifierOptions,
      deliverOptions: deliverOptions,
    );
  }

  @override
  Future<void> purchase(
    MobilePurchaseProduct product, {
    String? applicationUserName,
    bool sandboxTesting = false,
  }) async {
    await PurchaseCore.purchase(
      product,
      applicationUserName: applicationUserName,
      sandboxTesting: sandboxTesting,
    );
  }

  @override
  Future<void> restore() async {
    await PurchaseCore.restore();
  }

  @override
  Future<void> consume(MobilePurchaseProduct product) async {
    await PurchaseCore.consume(product: product);
  }

  @override
  MobilePurchaseProduct? getProduct(String productId) {
    return PurchaseCore.getProduct(productId);
  }

  @override
  List<MobilePurchaseProduct> getProducts() {
    return PurchaseCore.getProducts();
  }

  @override
  MobilePurchaseProduct? findById(String productId) {
    return PurchaseCore.findById(productId);
  }
}
